@@ -14,7 +14,7 @@
  * You should have received a copy of the GNU General Public License
  * along with YAD. If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2008-2013, Victor Ananjevsky <ananasik@gmail.com>
+ * Copyright (C) 2008-2014, Victor Ananjevsky <ananasik@gmail.com>
  */
 
 #include <glib/gprintf.h>
@@ -119,7 +119,7 @@ expand_action (gchar * cmd)
                     tb = gtk_text_view_get_buffer (GTK_TEXT_VIEW (g_slist_nth_data (fields, num)));
                     gtk_text_buffer_get_bounds (tb, &b, &e);
                     buf = gtk_text_buffer_get_text (tb, &b, &e, FALSE);
-                    txt = g_strescape (buf, NULL);
+                    txt = escape_str (buf);
                     g_string_append (xcmd, txt);
                     g_free (txt);
                     g_free (buf);
@@ -269,6 +269,7 @@ set_field_value (guint num, gchar * value)
       }
 
     case YAD_FIELD_BUTTON:
+    case YAD_FIELD_FULL_BUTTON:
       g_signal_connect (G_OBJECT (w), "clicked", G_CALLBACK (button_clicked_cb), value);
       break;
 
@@ -340,12 +341,6 @@ form_activate_cb (GtkEntry * entry, gpointer data)
     gtk_dialog_response (GTK_DIALOG (data), YAD_RESPONSE_OK);
 }
 
-static void
-text_size_allocate_cb (GtkWidget * w, GtkAllocation * al, gpointer data)
-{
-  gtk_widget_set_size_request (w, al->width, -1);
-}
-
 static void
 select_files_cb (GtkEntry * entry, GtkEntryIconPosition pos, GdkEventButton * event, gpointer data)
 {
@@ -405,6 +400,7 @@ select_files_cb (GtkEntry * entry, GtkEntryIconPosition pos, GdkEventButton * ev
               ptr = ptr->next;
             }
 
+          str->str[str->len-1] = '\0'; // remove last item separator
           gtk_entry_set_text (entry, str->str);
 
           g_slist_free (files);
@@ -578,6 +574,7 @@ form_create_widget (GtkWidget * dlg)
 
           /* add field label */
           if (fld->type != YAD_FIELD_CHECK && fld->type != YAD_FIELD_BUTTON &&
+              fld->type != YAD_FIELD_FULL_BUTTON &&
               fld->type != YAD_FIELD_LABEL && fld->type != YAD_FIELD_TEXT)
             {
               gchar *buf = g_strcompress (fld->name);
@@ -621,6 +618,7 @@ form_create_widget (GtkWidget * dlg)
 
             case YAD_FIELD_NUM:
               e = gtk_spin_button_new_with_range (0.0, 65525.0, 1.0);
+              gtk_entry_set_alignment (GTK_ENTRY (e), 1.0);
               gtk_widget_set_name (e, "yad-form-spin");
 #if !GTK_CHECK_VERSION(3,0,0)
               gtk_table_attach (GTK_TABLE (tbl), e, 1 + col * 2, 2 + col * 2, row, row + 1,
@@ -809,29 +807,22 @@ form_create_widget (GtkWidget * dlg)
               break;
 
             case YAD_FIELD_BUTTON:
-              {
-                gchar **buf = g_strsplit (fld->name, options.common_data.item_separator, 2);
-                e = gtk_button_new_from_stock (buf[0]);
-                if (buf[1])
-                  {
-                    if (options.data.no_markup)
-                      gtk_widget_set_tooltip_text (e, buf[1]);
-                    else
-                      gtk_widget_set_tooltip_markup (e, buf[1]);
-                  }
-                gtk_widget_set_name (e, "yad-form-button");
+            case YAD_FIELD_FULL_BUTTON:
+              e = gtk_button_new ();
+              gtk_container_add (GTK_CONTAINER (e), get_label (fld->name, 2));
+              gtk_widget_set_name (e, "yad-form-button");
+              gtk_button_set_alignment (GTK_BUTTON (e), 0.5, 0.5);
+              if (fld->type == YAD_FIELD_BUTTON)
                 gtk_button_set_relief (GTK_BUTTON (e), GTK_RELIEF_NONE);
 #if !GTK_CHECK_VERSION(3,0,0)
-                gtk_table_attach (GTK_TABLE (tbl), e, col * 2, 2 + col * 2, row, row + 1,
-                                  GTK_EXPAND | GTK_FILL, 0, 5, 5);
+              gtk_table_attach (GTK_TABLE (tbl), e, col * 2, 2 + col * 2, row, row + 1,
+                                GTK_EXPAND | GTK_FILL, 0, 5, 5);
 #else
-                gtk_grid_attach (GTK_GRID (tbl), e, col * 2, row, 2, 1);
-                gtk_widget_set_hexpand (e, TRUE);
+              gtk_grid_attach (GTK_GRID (tbl), e, col * 2, row, 2, 1);
+              gtk_widget_set_hexpand (e, TRUE);
 #endif
-                fields = g_slist_append (fields, e);
-                g_strfreev (buf);
-                break;
-              }
+              fields = g_slist_append (fields, e);
+              break;
 
             case YAD_FIELD_LABEL:
               if (fld->name[0])
@@ -846,7 +837,7 @@ form_create_widget (GtkWidget * dlg)
                   gtk_label_set_line_wrap (GTK_LABEL (e), TRUE);
                   gtk_label_set_selectable (GTK_LABEL (e), options.data.selectable_labels);
                   gtk_misc_set_alignment (GTK_MISC (e), options.common_data.align, 0.5);
-                  g_signal_connect_after (G_OBJECT (e), "size-allocate", G_CALLBACK (text_size_allocate_cb), NULL);
+                  //g_signal_connect_after (G_OBJECT (e), "size-allocate", G_CALLBACK (text_size_allocate_cb), NULL);
                   g_free (buf);
                 }
               else
@@ -1047,6 +1038,7 @@ form_print_result (void)
                       options.common_data.separator);
           break;
         case YAD_FIELD_BUTTON:
+        case YAD_FIELD_FULL_BUTTON:
         case YAD_FIELD_LABEL:
           if (options.common_data.quoted_output)
             g_printf ("''%s", options.common_data.separator);
