@@ -14,7 +14,7 @@
  * You should have received a copy of the GNU General Public License
  * along with YAD. If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2008-2013, Victor Ananjevsky <ananasik@gmail.com>
+ * Copyright (C) 2008-2014, Victor Ananjevsky <ananasik@gmail.com>
  */
 
 #include <stdlib.h>
@@ -33,12 +33,16 @@ static gboolean add_confirm_overwrite (const gchar *, const gchar *, gpointer, G
 static gboolean set_buttons_layout (const gchar *, const gchar *, gpointer, GError **);
 static gboolean set_align (const gchar *, const gchar *, gpointer, GError **);
 static gboolean set_justify (const gchar *, const gchar *, gpointer, GError **);
+static gboolean set_tab_pos (const gchar *, const gchar *, gpointer, GError **);
 static gboolean set_scale_value (const gchar *, const gchar *, gpointer, GError **);
 static gboolean set_ellipsize (const gchar *, const gchar *, gpointer, GError **);
 static gboolean set_expander (const gchar *, const gchar *, gpointer, GError **);
 static gboolean set_print_type (const gchar *, const gchar *, gpointer, GError **);
 static gboolean set_progress_log (const gchar *, const gchar *, gpointer, GError **);
+#ifndef G_OS_WIN32
 static gboolean parse_signal (const gchar *, const gchar *, gpointer, GError **);
+#endif
+static gboolean add_image_path (const gchar *, const gchar *, gpointer, GError **);
 
 static gboolean about_mode = FALSE;
 static gboolean version_mode = FALSE;
@@ -231,6 +235,18 @@ static GOptionEntry general_options[] = {
    &options.data.skip_taskbar,
    N_("Don't show window in taskbar"),
    NULL},
+  {"maximized", 0,
+   0,
+   G_OPTION_ARG_NONE,
+   &options.data.maximized,
+   N_("Set window maximized"),
+   NULL},
+  {"fullscreen", 0,
+   0,
+   G_OPTION_ARG_NONE,
+   &options.data.fullscreen,
+   N_("Set window fulscreen"),
+   NULL},
   {"plug", 0,
    0,
    G_OPTION_ARG_INT,
@@ -257,6 +273,12 @@ static GOptionEntry general_options[] = {
    N_("Print X Window Id to the stderr"),
    NULL},
 #endif
+  {"image-path", 0,
+   0,
+   G_OPTION_ARG_CALLBACK,
+   add_image_path,
+   N_("Add path for search icons by name"),
+   N_("PATH")},
   {NULL}
 };
 
@@ -536,7 +558,7 @@ static GOptionEntry form_options[] = {
    G_OPTION_ARG_CALLBACK,
    add_field,
    N_
-   ("Add field to form (TYPE - H, RO, NUM, CHK, CB, CBE, FL, SFL, MFL, DIR, CDIR, MDIR, FN, DT, SCL, CLR, BTN, LBL or TXT)"),
+   ("Add field to form (TYPE - H, RO, NUM, CHK, CB, CBE, FL, SFL, MFL, DIR, CDIR, MDIR, FN, DT, SCL, CLR, BTN, FBTN, LBL or TXT)"),
    N_("LABEL[:TYPE]")},
   {"align", 0,
    G_OPTION_FLAG_NOALIAS,
@@ -608,10 +630,10 @@ static GOptionEntry icons_options[] = {
    &options.icons_data.generic,
    N_("Use GenericName field instead of Name for icon label"),
    NULL},
-  {"stdin", 0,
-   0,
+  {"listen", 0,
+   G_OPTION_FLAG_NOALIAS,
    G_OPTION_ARG_NONE,
-   &options.icons_data.stdinput,
+   &options.common_data.listen,
    N_("Read data from stdin"),
    NULL},
   {"item-width", 0,
@@ -679,6 +701,12 @@ static GOptionEntry list_options[] = {
    &options.list_data.radiobox,
    N_("Use radioboxes for first column"),
    NULL},
+  {"no-click", 0,
+   G_OPTION_FLAG_REVERSE,
+   G_OPTION_ARG_NONE,
+   &options.list_data.clickable,
+   N_("Disable clickable column headers"),
+   NULL},
   {"separator",
    0,
    G_OPTION_FLAG_NOALIAS,
@@ -734,6 +762,12 @@ static GOptionEntry list_options[] = {
    &options.list_data.search_column,
    N_("Set the quick search column. Default is first column. Set it to 0 for disable searching"),
    N_("NUMBER")},
+  {"tooltip-column", 0,
+   0,
+   G_OPTION_ARG_INT,
+   &options.list_data.tooltip_column,
+   N_("Set the tooltip column"),
+   N_("NUMBER")},
   {"limit", 0,
    0,
    G_OPTION_ARG_INT,
@@ -753,7 +787,7 @@ static GOptionEntry list_options[] = {
    N_("Use regex in search"),
    NULL},
   {"listen", 0,
-   0,
+   G_OPTION_FLAG_NOALIAS,
    G_OPTION_ARG_NONE,
    &options.common_data.listen,
    N_("Listen for data on stdin in addition to command-line"),
@@ -792,6 +826,21 @@ static GOptionEntry multi_progress_options[] = {
    set_align,
    N_("Set alignment of bar labels (left, center or right)"),
    N_("TYPE")},
+  {"auto-close", 0,
+   G_OPTION_FLAG_NOALIAS,
+   G_OPTION_ARG_NONE,
+   &options.progress_data.autoclose,
+   /* xgettext: no-c-format */
+   N_("Dismiss the dialog when 100% of all bars has been reached"),
+   NULL},
+#ifndef G_OS_WIN32
+  {"auto-kill", 0,
+   G_OPTION_FLAG_NOALIAS,
+   G_OPTION_ARG_NONE,
+   &options.progress_data.autokill,
+   N_("Kill parent process if cancel button is pressed"),
+   NULL},
+#endif
   {NULL}
 };
 
@@ -814,11 +863,11 @@ static GOptionEntry notebook_options[] = {
    add_tab,
    N_("Add a tab to notebook"),
    N_("LABEL")},
-  {"align", 0,
+  {"tab-pos", 0,
    G_OPTION_FLAG_NOALIAS,
    G_OPTION_ARG_CALLBACK,
-   set_align,
-   N_("Set alignment of tab labels (left, center or right)"),
+   set_tab_pos,
+   N_("Set position of a notebook tabs (top, bottom, left or right)"),
    N_("TYPE")},
   {"tab-borders", 0,
    0,
@@ -843,7 +892,7 @@ static GOptionEntry notification_options[] = {
    N_("Set left-click action"),
    N_("CMD")},
   {"listen", 0,
-   0,
+   G_OPTION_FLAG_NOALIAS,
    G_OPTION_ARG_NONE,
    &options.common_data.listen,
    N_("Listen for commands on stdin"),
@@ -860,12 +909,24 @@ static GOptionEntry notification_options[] = {
    &options.common_data.item_separator,
    N_("Set separator character for menu items"),
    N_("SEPARATOR")},
+  {"menu", 0,
+   0,
+   G_OPTION_ARG_STRING,
+   &options.notification_data.menu,
+   N_("Set initial popup menu"),
+   N_("STRING")},
   {"no-middle", 0,
    G_OPTION_FLAG_REVERSE,
    G_OPTION_ARG_NONE,
    &options.notification_data.middle,
    N_("Disable exit on middle click"),
    NULL},
+  {"hidden", 0,
+   0,
+   G_OPTION_ARG_NONE,
+   &options.notification_data.hidden,
+   N_("Doesn't show icon at startup"),
+   NULL},
   {NULL}
 };
 
@@ -935,7 +996,7 @@ static GOptionEntry progress_options[] = {
    N_("Pulsate progress bar"),
    NULL},
   {"auto-close", 0,
-   0,
+   G_OPTION_FLAG_NOALIAS,
    G_OPTION_ARG_NONE,
    &options.progress_data.autoclose,
    /* xgettext: no-c-format */
@@ -943,7 +1004,7 @@ static GOptionEntry progress_options[] = {
    NULL},
 #ifndef G_OS_WIN32
   {"auto-kill", 0,
-   0,
+   G_OPTION_FLAG_NOALIAS,
    G_OPTION_ARG_NONE,
    &options.progress_data.autokill,
    N_("Kill parent process if cancel button is pressed"),
@@ -1120,7 +1181,7 @@ static GOptionEntry text_options[] = {
    N_("Make URI clickable"),
    NULL},
   {"listen", 0,
-   0,
+   G_OPTION_FLAG_NOALIAS,
    G_OPTION_ARG_NONE,
    &options.common_data.listen,
    N_("Listen for data on stdin in addition to file"),
@@ -1141,6 +1202,12 @@ static GOptionEntry misc_options[] = {
    &version_mode,
    N_("Print version"),
    NULL},
+  {"gtkrc", 0,
+   0,
+   G_OPTION_ARG_FILENAME,
+   &options.gtkrc_file,
+   N_("Load additional GTK settings from file"),
+   N_("FILENAME")},
   {NULL}
 };
 
@@ -1185,13 +1252,13 @@ add_button (const gchar * option_name, const gchar * value, gpointer data, GErro
 static gboolean
 set_text_align (const gchar * option_name, const gchar * value, gpointer data, GError ** err)
 {
-  if (g_ascii_strcasecmp (value, "left") == 0)
+  if (strcasecmp (value, "left") == 0)
     options.data.text_align = GTK_JUSTIFY_LEFT;
-  else if (g_ascii_strcasecmp (value, "right") == 0)
+  else if (strcasecmp (value, "right") == 0)
     options.data.text_align = GTK_JUSTIFY_RIGHT;
-  else if (g_ascii_strcasecmp (value, "center") == 0)
+  else if (strcasecmp (value, "center") == 0)
     options.data.text_align = GTK_JUSTIFY_CENTER;
-  else if (g_ascii_strcasecmp (value, "fill") == 0)
+  else if (strcasecmp (value, "fill") == 0)
     options.data.text_align = GTK_JUSTIFY_FILL;
   else
     g_printerr (_("Unknown align type: %s\n"), value);
@@ -1207,29 +1274,27 @@ add_column (const gchar * option_name, const gchar * value, gpointer data, GErro
 
   col = g_new0 (YadColumn, 1);
   col->name = g_strdup (cstr[0]);
-  if (g_ascii_strcasecmp (cstr[0], "@fore@") == 0)
+  if (strcasecmp (cstr[0], "@fore@") == 0)
     col->type = YAD_COLUMN_ATTR_FORE;
-  else if (g_ascii_strcasecmp (cstr[0], "@back@") == 0)
+  else if (strcasecmp (cstr[0], "@back@") == 0)
     col->type = YAD_COLUMN_ATTR_BACK;
-  else if (g_ascii_strcasecmp (cstr[0], "@font@") == 0)
+  else if (strcasecmp (cstr[0], "@font@") == 0)
     col->type = YAD_COLUMN_ATTR_FONT;
   else
     {
       if (cstr[1])
         {
-          if (g_ascii_strcasecmp (cstr[1], "NUM") == 0)
+          if (strcasecmp (cstr[1], "NUM") == 0)
             col->type = YAD_COLUMN_NUM;
-          else if (g_ascii_strcasecmp (cstr[1], "CHK") == 0)
+          else if (strcasecmp (cstr[1], "CHK") == 0)
             col->type = YAD_COLUMN_CHECK;
-          else if (g_ascii_strcasecmp (cstr[1], "RD") == 0)
+          else if (strcasecmp (cstr[1], "RD") == 0)
             col->type = YAD_COLUMN_RADIO;
-          else if (g_ascii_strcasecmp (cstr[1], "FLT") == 0)
+          else if (strcasecmp (cstr[1], "FLT") == 0)
             col->type = YAD_COLUMN_FLOAT;
-          else if (g_ascii_strcasecmp (cstr[1], "IMG") == 0)
+          else if (strcasecmp (cstr[1], "IMG") == 0)
             col->type = YAD_COLUMN_IMAGE;
-          else if (g_ascii_strcasecmp (cstr[1], "TIP") == 0)
-            col->type = YAD_COLUMN_TOOLTIP;
-          else if (g_ascii_strcasecmp (cstr[1], "HD") == 0)
+          else if (strcasecmp (cstr[1], "HD") == 0)
             col->type = YAD_COLUMN_HIDDEN;
           else
             col->type = YAD_COLUMN_TEXT;
@@ -1253,43 +1318,45 @@ add_field (const gchar * option_name, const gchar * value, gpointer data, GError
   fld->name = g_strdup (fstr[0]);
   if (fstr[1])
     {
-      if (g_ascii_strcasecmp (fstr[1], "H") == 0)
+      if (strcasecmp (fstr[1], "H") == 0)
         fld->type = YAD_FIELD_HIDDEN;
-      else if (g_ascii_strcasecmp (fstr[1], "RO") == 0)
+      else if (strcasecmp (fstr[1], "RO") == 0)
         fld->type = YAD_FIELD_READ_ONLY;
-      else if (g_ascii_strcasecmp (fstr[1], "NUM") == 0)
+      else if (strcasecmp (fstr[1], "NUM") == 0)
         fld->type = YAD_FIELD_NUM;
-      else if (g_ascii_strcasecmp (fstr[1], "CHK") == 0)
+      else if (strcasecmp (fstr[1], "CHK") == 0)
         fld->type = YAD_FIELD_CHECK;
-      else if (g_ascii_strcasecmp (fstr[1], "CB") == 0)
+      else if (strcasecmp (fstr[1], "CB") == 0)
         fld->type = YAD_FIELD_COMBO;
-      else if (g_ascii_strcasecmp (fstr[1], "CBE") == 0)
+      else if (strcasecmp (fstr[1], "CBE") == 0)
         fld->type = YAD_FIELD_COMBO_ENTRY;
-      else if (g_ascii_strcasecmp (fstr[1], "FL") == 0)
+      else if (strcasecmp (fstr[1], "FL") == 0)
         fld->type = YAD_FIELD_FILE;
-      else if (g_ascii_strcasecmp (fstr[1], "SFL") == 0)
+      else if (strcasecmp (fstr[1], "SFL") == 0)
         fld->type = YAD_FIELD_FILE_SAVE;
-      else if (g_ascii_strcasecmp (fstr[1], "DIR") == 0)
+      else if (strcasecmp (fstr[1], "DIR") == 0)
         fld->type = YAD_FIELD_DIR;
-      else if (g_ascii_strcasecmp (fstr[1], "CDIR") == 0)
+      else if (strcasecmp (fstr[1], "CDIR") == 0)
         fld->type = YAD_FIELD_DIR_CREATE;
-      else if (g_ascii_strcasecmp (fstr[1], "FN") == 0)
+      else if (strcasecmp (fstr[1], "FN") == 0)
         fld->type = YAD_FIELD_FONT;
-      else if (g_ascii_strcasecmp (fstr[1], "CLR") == 0)
+      else if (strcasecmp (fstr[1], "CLR") == 0)
         fld->type = YAD_FIELD_COLOR;
-      else if (g_ascii_strcasecmp (fstr[1], "MFL") == 0)
+      else if (strcasecmp (fstr[1], "MFL") == 0)
         fld->type = YAD_FIELD_MFILE;
-      else if (g_ascii_strcasecmp (fstr[1], "MDIR") == 0)
+      else if (strcasecmp (fstr[1], "MDIR") == 0)
         fld->type = YAD_FIELD_MDIR;
-      else if (g_ascii_strcasecmp (fstr[1], "DT") == 0)
+      else if (strcasecmp (fstr[1], "DT") == 0)
         fld->type = YAD_FIELD_DATE;
-      else if (g_ascii_strcasecmp (fstr[1], "SCL") == 0)
+      else if (strcasecmp (fstr[1], "SCL") == 0)
         fld->type = YAD_FIELD_SCALE;
-      else if (g_ascii_strcasecmp (fstr[1], "BTN") == 0)
+      else if (strcasecmp (fstr[1], "BTN") == 0)
         fld->type = YAD_FIELD_BUTTON;
-      else if (g_ascii_strcasecmp (fstr[1], "LBL") == 0)
+      else if (strcasecmp (fstr[1], "FBTN") == 0)
+        fld->type = YAD_FIELD_FULL_BUTTON;
+      else if (strcasecmp (fstr[1], "LBL") == 0)
         fld->type = YAD_FIELD_LABEL;
-      else if (g_ascii_strcasecmp (fstr[1], "TXT") == 0)
+      else if (strcasecmp (fstr[1], "TXT") == 0)
         fld->type = YAD_FIELD_TEXT;
       else
         fld->type = YAD_FIELD_SIMPLE;
@@ -1312,9 +1379,9 @@ add_bar (const gchar * option_name, const gchar * value, gpointer data, GError *
   bar->name = g_strdup (bstr[0]);
   if (bstr[1])
     {
-      if (g_ascii_strcasecmp (bstr[1], "RTL") == 0)
+      if (strcasecmp (bstr[1], "RTL") == 0)
         bar->type = YAD_PROGRESS_RTL;
-      else if (g_ascii_strcasecmp (bstr[1], "PULSE") == 0)
+      else if (strcasecmp (bstr[1], "PULSE") == 0)
         bar->type = YAD_PROGRESS_PULSE;
       else
         bar->type = YAD_PROGRESS_NORMAL;
@@ -1381,15 +1448,15 @@ add_confirm_overwrite (const gchar * option_name, const gchar * value, gpointer
 static gboolean
 set_buttons_layout (const gchar * option_name, const gchar * value, gpointer data, GError ** err)
 {
-  if (g_ascii_strcasecmp (value, "spread") == 0)
+  if (strcasecmp (value, "spread") == 0)
     options.data.buttons_layout = GTK_BUTTONBOX_SPREAD;
-  else if (g_ascii_strcasecmp (value, "edge") == 0)
+  else if (strcasecmp (value, "edge") == 0)
     options.data.buttons_layout = GTK_BUTTONBOX_EDGE;
-  else if (g_ascii_strcasecmp (value, "start") == 0)
+  else if (strcasecmp (value, "start") == 0)
     options.data.buttons_layout = GTK_BUTTONBOX_START;
-  else if (g_ascii_strcasecmp (value, "end") == 0)
+  else if (strcasecmp (value, "end") == 0)
     options.data.buttons_layout = GTK_BUTTONBOX_END;
-  else if (g_ascii_strcasecmp (value, "center") == 0)
+  else if (strcasecmp (value, "center") == 0)
     options.data.buttons_layout = GTK_BUTTONBOX_CENTER;
   else
     g_printerr (_("Unknown buttons layout type: %s\n"), value);
@@ -1400,11 +1467,11 @@ set_buttons_layout (const gchar * option_name, const gchar * value, gpointer dat
 static gboolean
 set_align (const gchar * option_name, const gchar * value, gpointer data, GError ** err)
 {
-  if (g_ascii_strcasecmp (value, "left") == 0)
+  if (strcasecmp (value, "left") == 0)
     options.common_data.align = 0.0;
-  else if (g_ascii_strcasecmp (value, "right") == 0)
+  else if (strcasecmp (value, "right") == 0)
     options.common_data.align = 1.0;
-  else if (g_ascii_strcasecmp (value, "center") == 0)
+  else if (strcasecmp (value, "center") == 0)
     options.common_data.align = 0.5;
   else
     g_printerr (_("Unknown align type: %s\n"), value);
@@ -1415,13 +1482,13 @@ set_align (const gchar * option_name, const gchar * value, gpointer data, GError
 static gboolean
 set_justify (const gchar * option_name, const gchar * value, gpointer data, GError ** err)
 {
-  if (g_ascii_strcasecmp (value, "left") == 0)
+  if (strcasecmp (value, "left") == 0)
     options.text_data.justify = GTK_JUSTIFY_LEFT;
-  else if (g_ascii_strcasecmp (value, "right") == 0)
+  else if (strcasecmp (value, "right") == 0)
     options.text_data.justify = GTK_JUSTIFY_RIGHT;
-  else if (g_ascii_strcasecmp (value, "center") == 0)
+  else if (strcasecmp (value, "center") == 0)
     options.text_data.justify = GTK_JUSTIFY_CENTER;
-  else if (g_ascii_strcasecmp (value, "fill") == 0)
+  else if (strcasecmp (value, "fill") == 0)
     options.text_data.justify = GTK_JUSTIFY_FILL;
   else
     g_printerr (_("Unknown justification type: %s\n"), value);
@@ -1429,6 +1496,23 @@ set_justify (const gchar * option_name, const gchar * value, gpointer data, GErr
   return TRUE;
 }
 
+static gboolean
+set_tab_pos (const gchar * option_name, const gchar * value, gpointer data, GError ** err)
+{
+  if (strcasecmp (value, "top") == 0)
+    options.notebook_data.pos = GTK_POS_TOP;
+  else if (strcasecmp (value, "bottom") == 0)
+    options.notebook_data.pos = GTK_POS_BOTTOM;
+  else if (strcasecmp (value, "left") == 0)
+    options.notebook_data.pos = GTK_POS_LEFT;
+  else if (strcasecmp (value, "right") == 0)
+    options.notebook_data.pos = GTK_POS_RIGHT;
+  else
+    g_printerr (_("Unknown tab position type: %s\n"), value);
+
+  return TRUE;
+}
+
 static gboolean
 set_expander (const gchar * option_name, const gchar * value, gpointer data, GError ** err)
 {
@@ -1451,13 +1535,13 @@ set_scale_value (const gchar * option_name, const gchar * value, gpointer data,
 static gboolean
 set_ellipsize (const gchar * option_name, const gchar * value, gpointer data, GError ** err)
 {
-  if (g_ascii_strcasecmp (value, "none") == 0)
+  if (strcasecmp (value, "none") == 0)
     options.list_data.ellipsize = PANGO_ELLIPSIZE_NONE;
-  else if (g_ascii_strcasecmp (value, "start") == 0)
+  else if (strcasecmp (value, "start") == 0)
     options.list_data.ellipsize = PANGO_ELLIPSIZE_START;
-  else if (g_ascii_strcasecmp (value, "middle") == 0)
+  else if (strcasecmp (value, "middle") == 0)
     options.list_data.ellipsize = PANGO_ELLIPSIZE_MIDDLE;
-  else if (g_ascii_strcasecmp (value, "end") == 0)
+  else if (strcasecmp (value, "end") == 0)
     options.list_data.ellipsize = PANGO_ELLIPSIZE_END;
   else
     g_printerr (_("Unknown ellipsize type: %s\n"), value);
@@ -1468,11 +1552,11 @@ set_ellipsize (const gchar * option_name, const gchar * value, gpointer data, GE
 static gboolean
 set_print_type (const gchar * option_name, const gchar * value, gpointer data, GError ** err)
 {
-  if (g_ascii_strcasecmp (value, "text") == 0)
+  if (strcasecmp (value, "text") == 0)
     options.print_data.type = YAD_PRINT_TEXT;
-  else if (g_ascii_strcasecmp (value, "image") == 0)
+  else if (strcasecmp (value, "image") == 0)
     options.print_data.type = YAD_PRINT_IMAGE;
-  else if (g_ascii_strcasecmp (value, "raw") == 0)
+  else if (strcasecmp (value, "raw") == 0)
     options.print_data.type = YAD_PRINT_RAW;
   else
     g_printerr (_("Unknown source type: %s\n"), value);
@@ -1491,6 +1575,16 @@ set_progress_log (const gchar * option_name, const gchar * value, gpointer data,
   return TRUE;
 }
 
+static gboolean
+add_image_path (const gchar * option_name, const gchar * value, gpointer data, GError ** err)
+{
+  if (value)
+    gtk_icon_theme_append_search_path (settings.icon_theme, value);
+
+  return TRUE;
+}
+
+#ifndef G_OS_WIN32
 static gboolean
 parse_signal (const gchar * option_name, const gchar * value, gpointer data, GError ** err)
 {
@@ -1590,6 +1684,7 @@ parse_signal (const gchar * option_name, const gchar * value, gpointer data, GEr
 
   return TRUE;
 }
+#endif
 
 void
 yad_set_mode (void)
@@ -1639,6 +1734,7 @@ yad_options_init (void)
   options.mode = YAD_MODE_MESSAGE;
   options.rest_file = NULL;
   options.extra_data = NULL;
+  options.gtkrc_file = NULL;
 #ifndef G_OS_WIN32
   options.kill_parent = 0;
   options.print_xid = FALSE;
@@ -1681,6 +1777,8 @@ yad_options_init (void)
   options.data.mouse = FALSE;
   options.data.undecorated = FALSE;
   options.data.skip_taskbar = FALSE;
+  options.data.maximized = FALSE;
+  options.data.fullscreen = FALSE;
 
   /* Initialize common data */
   options.common_data.uri = NULL;
@@ -1741,7 +1839,6 @@ yad_options_init (void)
   options.icons_data.directory = NULL;
   options.icons_data.compact = FALSE;
   options.icons_data.generic = FALSE;
-  options.icons_data.stdinput = FALSE;
   options.icons_data.width = -1;
   options.icons_data.term = settings.term;
   options.icons_data.sort_by_name = FALSE;
@@ -1758,10 +1855,12 @@ yad_options_init (void)
   options.list_data.hide_column = 0;
   options.list_data.expand_column = -1; // must be -1 for disable expand by default (keep the original behavior)
   options.list_data.search_column = 0;
+  options.list_data.tooltip_column = 0;
   options.list_data.limit = 0;
   options.list_data.ellipsize = PANGO_ELLIPSIZE_NONE;
   options.list_data.dclick_action = NULL;
   options.list_data.regex_search = FALSE;
+  options.list_data.clickable = TRUE;
 
   /* Initialize multiprogress data */
   options.multi_progress_data.bars = NULL;
@@ -1769,10 +1868,13 @@ yad_options_init (void)
   /* Initialize notebook data */
   options.notebook_data.tabs = NULL;
   options.notebook_data.borders = 5;
+  options.notebook_data.pos = GTK_POS_TOP;
   options.notebook_data.key = -1;
 
   /* Initialize notification data */
   options.notification_data.middle = TRUE;
+  options.notification_data.hidden = FALSE;
+  options.notification_data.menu = NULL;
 
   /* Initialize print data */
   options.print_data.type = YAD_PRINT_TEXT;
