@@ -14,7 +14,7 @@
  * You should have received a copy of the GNU General Public License
  * along with YAD. If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2008-2013, Victor Ananjevsky <ananasik@gmail.com>
+ * Copyright (C) 2008-2014, Victor Ananjevsky <ananasik@gmail.com>
  */
 
 #include <errno.h>
@@ -331,19 +331,26 @@ handle_stdin (GIOChannel * channel, GIOCondition condition, gpointer data)
           return FALSE;
         }
 
-      if (string->len > 0)
+      if (string->str[0] == '\014')
+	{
+          GtkTextIter start, end;
+
+	  /* clear text if ^L received */
+          gtk_text_buffer_get_start_iter (text_buffer, &start);
+          gtk_text_buffer_get_end_iter (text_buffer, &end);
+          gtk_text_buffer_delete (text_buffer, &start, &end);
+	}
+      else if (string->len > 0)
         {
           GtkTextIter end;
-          gchar *utftext;
-          gsize utflen;
 
           gtk_text_buffer_get_end_iter (text_buffer, &end);
 
           if (!g_utf8_validate (string->str, string->len, NULL))
             {
-              utftext =
-                g_convert_with_fallback (string->str, string->len, "UTF-8", "ISO-8859-1", NULL, NULL, &utflen, NULL);
-              gtk_text_buffer_insert (text_buffer, &end, utftext, utflen);
+              gchar *utftext =
+                g_convert_with_fallback (string->str, string->len, "UTF-8", "ISO-8859-1", NULL, NULL, NULL, NULL);
+              gtk_text_buffer_insert (text_buffer, &end, utftext, -1);
               g_free (utftext);
             }
           else
@@ -400,7 +407,7 @@ fill_buffer_from_file ()
       gtk_text_buffer_insert (text_buffer, &iter, buf, leftover - buf);
 
       remaining = (buf + remaining + count) - leftover;
-      g_memmove (buf, leftover, remaining);
+      memmove (buf, leftover, remaining);
 
       if (remaining > 6 || count < to_read)
         break;
