@@ -14,7 +14,7 @@
  * You should have received a copy of the GNU General Public License
  * along with YAD. If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2008-2013, Victor Ananjevsky <ananasik@gmail.com>
+ * Copyright (C) 2008-2014, Victor Ananjevsky <ananasik@gmail.com>
  */
 
 #include <stdlib.h>
@@ -53,6 +53,9 @@ read_settings (void)
   settings.ignore_unknown = TRUE;
   settings.max_tab = 100;
 
+  settings.print_settings = NULL;
+  settings.page_setup = NULL;
+
   filename = g_build_filename (g_get_user_config_dir (), SETTINGS_FILE, NULL);
 
   if (g_file_test (filename, G_FILE_TEST_EXISTS))
@@ -91,6 +94,9 @@ read_settings (void)
             settings.ignore_unknown = g_key_file_get_boolean (kf, "General", "ignore_unknown_options", NULL);
           if (g_key_file_has_key (kf, "General", "max_tab", NULL))
             settings.max_tab = g_key_file_get_integer (kf, "General", "max_tab", NULL);
+
+          settings.print_settings = gtk_print_settings_new_from_key_file (kf, NULL, NULL);
+          settings.page_setup = gtk_page_setup_new_from_key_file (kf, NULL, NULL);
         }
 
       g_key_file_free (kf);
@@ -141,11 +147,16 @@ write_settings (void)
   g_key_file_set_integer (kf, "General", "max_tab", settings.max_tab);
   g_key_file_set_comment (kf, "General", "max_tab", "Maximum number of tabs in notebook", NULL);
 
+  if (settings.print_settings)
+    gtk_print_settings_to_key_file (settings.print_settings, kf, NULL);
+  if (settings.page_setup)
+    gtk_page_setup_to_key_file (settings.page_setup, kf, NULL);
+
   context = g_key_file_to_data (kf, NULL, NULL);
 
   g_key_file_free (kf);
 
-  if (g_mkdir_with_parents (g_get_user_config_dir (), 0644) != -1)
+  if (g_mkdir_with_parents (g_get_user_config_dir (), 0755) != -1)
     {
       gchar *filename = g_build_filename (g_get_user_config_dir (), SETTINGS_FILE, NULL);
       g_file_set_contents (filename, context, -1, NULL);
@@ -227,113 +238,117 @@ split_arg (const gchar * str)
   return res;
 }
 
-char *
-escape_markup (char *str)
+YadNTabs *
+get_tabs (key_t key, gboolean create)
 {
-  char *res, *buf = str;
-  unsigned i = 0, len;
+  YadNTabs *t = NULL;
+  int shmid, i;
 
-  if (!str)
-    return NULL;
-
-  len = strlen (str);
-  res = (char *) calloc (len + 1, sizeof (char));
-
-  while (*buf)
+  /* get shared memory */
+  if (create)
     {
-      switch (*buf)
+      if ((shmid = shmget (key, (settings.max_tab + 1) * sizeof (YadNTabs), IPC_CREAT | IPC_EXCL | 0644)) == -1)
         {
-        case '&':
-          len += 4;
-          res = (char *) realloc (res, len + 1);
-          strcpy (res + i, "&amp;");
-          i += 5;
-          break;
-        case '<':
-          len += 3;
-          res = (char *) realloc (res, len + 1);
-          strcpy (res + i, "&lt;");
-          i += 4;
-          break;
-        case '>':
-          len += 3;
-          res = (char *) realloc (res, len + 1);
-          strcpy (res + i, "&gt;");
-          i += 4;
-          break;
-        case '"':
-          len += 5;
-          res = (char *) realloc (res, len + 1);
-          strcpy (res + i, "&quot;");
-          i += 6;
-          break;
-        case '\'':
-          len += 5;
-          res = (char *) realloc (res, len + 1);
-          strcpy (res + i, "&apos;");
-          i += 6;
-          break;
-        default:
-          *(res + i) = *buf;
-          i++;
-          break;
+          g_printerr ("yad: cannot create shared memory for key %ld: %s\n", key, strerror (errno));
+          return NULL;
+        }
+    }
+  else
+    {
+      if ((shmid = shmget (key, (settings.max_tab + 1) * sizeof (YadNTabs), 0)) == -1)
+        {
+          if (errno != ENOENT)
+            g_printerr ("yad: cannot get shared memory for key %ld: %s\n", key, strerror (errno));
+          return NULL;
         }
-      buf++;
     }
-  res[i] = '\0';
 
-  return res;
+  /* attach shared memory */
+  if ((t = shmat (shmid, NULL, 0)) == (YadNTabs *) -1)
+    {
+      g_printerr ("yad: cannot attach shared memory for key %ld: %s\n", key, strerror (errno));
+      return NULL;
+    }
+
+  /* initialize memory */
+  if (create)
+    {
+      for (i = 0; i < settings.max_tab + 1; i++)
+        {
+          t[i].pid = -1;
+          t[i].xid = 0;
+        }
+      t[0].pid = shmid;
+    }
+
+  return t;
 }
 
-char *
-unescape_markup (char *str)
+GtkWidget *
+get_label (gchar *str, guint border)
 {
-  char *res, *buf = str;
-  int i = 0;
+  GtkWidget *a, *t, *i, *l;
+  GtkStockItem it;
+  gchar **vals;
 
   if (!str)
-    return NULL;
+    return gtk_label_new ("");
 
-  res = calloc (strlen (str) + 1, sizeof (char));
+  l = i = NULL;
 
-  while (*buf)
+  a = gtk_alignment_new (0.0, 0.5, 0, 0);
+  gtk_container_set_border_width (GTK_CONTAINER (a), border);
+
+#if !GTK_CHECK_VERSION(3,0,0)
+  t = gtk_hbox_new (FALSE, 0);
+#else
+  t = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
+#endif
+  gtk_container_add (GTK_CONTAINER (a), t);
+
+  vals = g_strsplit_set (str, options.common_data.item_separator, 3);
+  if (gtk_stock_lookup (vals[0], &it))
     {
-      if (*buf == '&')
-        {
-          buf++;
-          if (strncmp (buf, "lt;", 3) == 0)
-            {
-              res[i] = '<';
-              buf += 3;
-            }
-          else if (strncmp (buf, "gt;", 3) == 0)
-            {
-              res[i] = '>';
-              buf += 3;
-            }
-          else if (strncmp (buf, "amp;", 4) == 0)
-            {
-              res[i] = '&';
-              buf += 4;
-            }
-          else if (strncmp (buf, "quot;", 5) == 0)
-            {
-              res[i] = '"';
-              buf += 5;
-            }
-          else if (strncmp (buf, "apos;", 5) == 0)
-            {
-              res[i] = '\'';
-              buf += 5;
-            }
-        }
-      else
-        res[i] = *buf++;
-      i++;
-    }
-  res[i] = '\0';
+      l = gtk_label_new_with_mnemonic (it.label);
+      gtk_misc_set_alignment (GTK_MISC (l), 0.0, 0.5);
 
-  return res;
+      i = gtk_image_new_from_pixbuf (get_pixbuf (it.stock_id, YAD_SMALL_ICON));
+    }
+  else
+    {
+      if (vals[0] && *vals[0])
+        {
+          l = gtk_label_new (NULL);
+          if (!options.data.no_markup)
+            gtk_label_set_markup_with_mnemonic (GTK_LABEL (l), vals[0]);
+          else
+            gtk_label_set_text_with_mnemonic (GTK_LABEL (l), vals[0]);
+          gtk_misc_set_alignment (GTK_MISC (l), 0.0, 0.5);
+        }
+
+      if (vals[1] && *vals[1])
+        i = gtk_image_new_from_pixbuf (get_pixbuf (vals[1], YAD_SMALL_ICON));
+    }
+
+  if (i)
+    gtk_box_pack_start (GTK_BOX (t), i, FALSE, FALSE, 1);
+  if (l)
+    gtk_box_pack_start (GTK_BOX (t), l, FALSE, FALSE, 1);
+
+  /* !!! must check both 1 and 2 values for !NULL */
+  if (vals[1] && vals[2] && *vals[2])
+    {
+      if (!options.data.no_markup)
+        gtk_widget_set_tooltip_markup (t, vals[2]);
+      else
+        gtk_widget_set_tooltip_text (t, vals[2]);
+    }
+
+  g_strfreev (vals);
+
+  gtk_widget_show_all (a);
+
+  return a;
 }
 
 char *
@@ -375,49 +390,3 @@ escape_str (char *str)
 
   return res;
 }
-
-YadNTabs *
-get_tabs (key_t key, gboolean create)
-{
-  YadNTabs *t = NULL;
-  int shmid, i;
-
-  /* get shared memory */
-  if (create)
-    {
-      if ((shmid = shmget (key, (settings.max_tab + 1) * sizeof (YadNTabs), IPC_CREAT | IPC_EXCL | 0644)) == -1)
-        {
-          g_printerr ("yad: cannot create shared memory for key %ld: %s", key, strerror (errno));
-          return NULL;
-        }
-    }
-  else
-    {
-      if ((shmid = shmget (key, (settings.max_tab + 1) * sizeof (YadNTabs), 0)) == -1)
-        {
-          if (errno != ENOENT)
-            g_printerr ("yad: cannot get shared memory for key %ld: %s", key, strerror (errno));
-          return NULL;
-        }
-    }
-
-  /* attach shared memory */
-  if ((t = shmat (shmid, NULL, 0)) == (YadNTabs *) -1)
-    {
-      g_printerr ("yad: cannot attach shared memory for key %ld: %s", key, strerror (errno));
-      return NULL;
-    }
-
-  /* initialize memory */
-  if (create)
-    {
-      for (i = 0; i < settings.max_tab + 1; i++)
-        {
-          t[i].pid = -1;
-          t[i].xid = 0;
-        }
-      t[0].pid = shmid;
-    }
-
-  return t;
-}
