@@ -14,7 +14,7 @@
  * You should have received a copy of the GNU General Public License
  * along with YAD. If not, see <http://www.gnu.org/licenses/>.
  *
- * Copyright (C) 2008-2013, Victor Ananjevsky <ananasik@gmail.com>
+ * Copyright (C) 2008-2014, Victor Ananjevsky <ananasik@gmail.com>
  */
 
 #ifndef _YAD_H_
@@ -36,6 +36,8 @@
 
 G_BEGIN_DECLS
 
+#define YAD_SETTINGS_FILE "yad.conf"
+
 #define YAD_RESPONSE_OK         0
 #define YAD_RESPONSE_CANCEL     1
 #define YAD_RESPONSE_TIMEOUT   	70
@@ -83,6 +85,7 @@ typedef enum {
   YAD_FIELD_DATE,
   YAD_FIELD_SCALE,
   YAD_FIELD_BUTTON,
+  YAD_FIELD_FULL_BUTTON,
   YAD_FIELD_LABEL,
   YAD_FIELD_TEXT,
 } YadFieldType;
@@ -94,7 +97,6 @@ typedef enum {
   YAD_COLUMN_CHECK,
   YAD_COLUMN_RADIO,
   YAD_COLUMN_IMAGE,
-  YAD_COLUMN_TOOLTIP,
   YAD_COLUMN_HIDDEN,
   YAD_COLUMN_ATTR_FORE,
   YAD_COLUMN_ATTR_BACK,
@@ -176,6 +178,8 @@ typedef struct {
   gboolean mouse;
   gboolean undecorated;
   gboolean skip_taskbar;
+  gboolean maximized;
+  gboolean fullscreen;
 } YadData;
 
 typedef struct {
@@ -232,7 +236,6 @@ typedef struct {
   gboolean generic;
   gboolean descend;
   gboolean sort_by_name;
-  gboolean stdinput;
   gboolean single_click;
   guint width;
   gchar *term;
@@ -248,10 +251,12 @@ typedef struct {
   gint hide_column;
   gint expand_column;
   gint search_column;
+  gint tooltip_column;
   guint limit;
   PangoEllipsizeMode ellipsize;
   gchar *dclick_action;
   gboolean regex_search;
+  gboolean clickable;
 } YadListData;
 
 typedef struct {
@@ -261,11 +266,14 @@ typedef struct {
 typedef struct {
   GSList *tabs;
   guint borders;
+  GtkPositionType pos;
   key_t key;
 } YadNotebookData;
 
 typedef struct {
   gboolean middle;
+  gboolean hidden;
+  gchar *menu;
 } YadNotificationData;
 
 typedef struct {
@@ -350,6 +358,8 @@ typedef struct {
   YadScaleData scale_data;
   YadTextData text_data;
 
+  gchar *gtkrc_file;
+
   gchar *rest_file;
   gchar **extra_data;
 
@@ -384,6 +394,10 @@ typedef struct {
   GdkPixbuf *small_fallback_image;
   gchar *term;
   guint max_tab;
+
+  GtkPrintSettings *print_settings;
+  GtkPageSetup *page_setup;
+
 } YadSettings;
 
 extern YadSettings settings;
@@ -453,12 +467,12 @@ inline void strip_new_line (gchar * str);
 
 gchar **split_arg (const gchar * str);
 
-char *escape_markup (char *str);
-char *unescape_markup (char *str);
-char *escape_str (char *str);
-
 YadNTabs *get_tabs (key_t key, gboolean create);
 
+GtkWidget *get_label (gchar *str, guint border);
+
+char *escape_str (char *str);
+
 G_END_DECLS
 
 #endif /* _YAD_H_ */
